@@ -18,7 +18,6 @@
 //! in range, and provides default values for any parameters that are
 //! missing.
 
-use std::convert::TryInto;
 use tor_units::{
     BoundedInt32, IntegerDays, IntegerMilliseconds, IntegerSeconds, Percentage, SendMeVersion,
 };
@@ -130,7 +129,7 @@ declare_net_parameters! {
 #[non_exhaustive]
 pub struct NetParameters {
     /// A weighting factor for bandwidth calculations
-    pub bw_weight_scale: BoundedInt32<0, { i32::MAX }> = (10_000)
+    pub bw_weight_scale: BoundedInt32<1, { i32::MAX }> = (10_000)
         from "bwweightscale",
     /// If true, do not attempt to learn circuit-build timeouts at all.
     pub cbt_learning_disabled: BoundedInt32<0, 1> = (0)
@@ -145,12 +144,10 @@ pub struct NetParameters {
         from "cbtrecentcount",
     /// How many timeouts (in the last `cbt_success_count` observations)
     /// indicates that our circuit timeouts are too low?
-    // XXXX-SPEC 10000 is greater than 1000 for cbt_success_count.
     pub cbt_max_timeouts: BoundedInt32<3, 10_000> = (18)
         from "cbtmaxtimeouts",
     /// Smallest number of circuit build times we have to view in order to use
     /// our Pareto-based circuit timeout estimator.
-    // XXXX-SPEC 10000 disables this.
     pub cbt_min_circs_for_estimate: BoundedInt32<1, 10_000> = (100)
         from "cbtmincircs",
     /// Quantile to use when determining the correct circuit timeout value
@@ -451,7 +448,6 @@ mod test {
 
     #[test]
     fn all_parameters() {
-        use std::convert::TryFrom;
         use std::time::Duration;
         let mut p = NetParameters::default();
         let mp = [
